Uses of Interface
com.volcengine.auth.Authentication
-
Packages that use Authentication Package Description com.volcengine com.volcengine.sign -
-
Uses of Authentication in com.volcengine
Methods in com.volcengine that return Authentication Modifier and Type Method Description AuthenticationApiClient. getAuthentication(String authName)Get authentication for the given name.Methods in com.volcengine that return types with arguments of type Authentication Modifier and Type Method Description Map<String,Authentication>ApiClient. getAuthentications()Get authentications (key: authentication name, value: authentication). -
Uses of Authentication in com.volcengine.sign
Classes in com.volcengine.sign that implement Authentication Modifier and Type Class Description classVolcstackSign[email protected] 2022/3/18 13:13
-