Uses of Class
com.volcengine.HttpMethod
-
Packages that use HttpMethod Package Description com.volcengine -
-
Uses of HttpMethod in com.volcengine
Methods in com.volcengine that return HttpMethod Modifier and Type Method Description HttpMethodUniversalRequest. getHttpMethod()static HttpMethodHttpMethod. valueOf(String name)Returns the enum constant of this type with the specified name.static HttpMethod[]HttpMethod. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.volcengine with parameters of type HttpMethod Modifier and Type Method Description voidUniversalRequest. setHttpMethod(HttpMethod httpMethod)Constructors in com.volcengine with parameters of type HttpMethod Constructor Description UniversalRequest(String serviceName, String action, String version, HttpMethod httpMethod, ContentType contentType)
-