Uses of Class
com.volcengine.observability.debugger.LogLevel
-
Packages that use LogLevel Package Description com.volcengine.observability.debugger -
-
Uses of LogLevel in com.volcengine.observability.debugger
Methods in com.volcengine.observability.debugger that return LogLevel Modifier and Type Method Description static LogLevelLogLevel. valueOf(String name)Returns the enum constant of this type with the specified name.static LogLevel[]LogLevel. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.volcengine.observability.debugger with parameters of type LogLevel Modifier and Type Method Description static longLogLevel. combine(LogLevel... modes)组合多个模式为 flagsvoidSdkDebugLog. debug(LogLevel logLevelEnum, String msg, Object... args)booleanSdkDebugLog. matches(LogLevel logLevelEnum)
-