Enum LogLevel
- java.lang.Object
-
- java.lang.Enum<LogLevel>
-
- com.volcengine.observability.debugger.LogLevel
-
- All Implemented Interfaces:
Serializable,Comparable<LogLevel>
public enum LogLevel extends Enum<LogLevel>
-
-
Enum Constant Summary
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static longcombine(LogLevel... modes)组合多个模式为 flagslongmask()booleanmatches(long flags)判断当前模式是否包含某个标志位static LogLevelvalueOf(String name)Returns the enum constant of this type with the specified name.static LogLevel[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
LOG_DEBUG_OFF
public static final LogLevel LOG_DEBUG_OFF
-
LOG_DEBUG_WITH_REQUEST
public static final LogLevel LOG_DEBUG_WITH_REQUEST
-
LOG_DEBUG_WITH_REQUEST_BODY
public static final LogLevel LOG_DEBUG_WITH_REQUEST_BODY
-
LOG_DEBUG_WITH_REQUEST_ID
public static final LogLevel LOG_DEBUG_WITH_REQUEST_ID
-
LOG_DEBUG_WITH_RESPONSE
public static final LogLevel LOG_DEBUG_WITH_RESPONSE
-
LOG_DEBUG_WITH_RESPONSE_BODY
public static final LogLevel LOG_DEBUG_WITH_RESPONSE_BODY
-
LOG_DEBUG_WITH_SIGNING
public static final LogLevel LOG_DEBUG_WITH_SIGNING
-
LOG_DEBUG_WITH_ENDPOINT
public static final LogLevel LOG_DEBUG_WITH_ENDPOINT
-
LOG_DEBUG_WITH_REQUEST_RETRIES
public static final LogLevel LOG_DEBUG_WITH_REQUEST_RETRIES
-
LOG_DEBUG_WITH_CONFIG
public static final LogLevel LOG_DEBUG_WITH_CONFIG
-
LOG_DEBUG_ALL
public static final LogLevel LOG_DEBUG_ALL
-
-
Method Detail
-
values
public static LogLevel[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (LogLevel c : LogLevel.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static LogLevel valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
mask
public long mask()
-
combine
public static long combine(LogLevel... modes)
组合多个模式为 flags
-
matches
public boolean matches(long flags)
判断当前模式是否包含某个标志位
-
-